# react-native-bugsee

[![NPM version][npm-image]][npm-url]

[npm-url]: https://badge.fury.io/js/react-native-bugsee.svg
[npm-image]: https://badge.fury.io/js/react-native-bugsee.svg

Bugsee is free crash and bug reporting with video, network and logs. Sign up for a service at [https://www.bugsee.com](https://www.bugsee.com). This Native Module allows for an easy integration of the Bugsee SDK with React Native based application on iOS and Android.

Installation of **react-native-bugsee** module allows for a richer integration and brings the ability to further control Bugsee from within your Javascript code.

## Supported SDK Versions

- iOS : 5.5.3
- Android : 5.6.2

## Installation

For installation instructions, please refer to the [documentation](https://docs.bugsee.com/sdk/react_native/installation/).

## Usage

First, import Bugsee module into your javascript code:

```javascript
import Bugsee from "react-native-bugsee";
```

### User events

User events can be attached to the report, events are identified by a string and can have an optional dictionary of parameters that will be stored and passed along with the report.

```javascript
// Without any additional parameters
Bugsee.event("payment_processed");

// ...our with additional custom parameters
Bugsee.event("payment_processed", {
  amount: 125,
  currency: "USD",
});
```

### User traces

User traces can be attached to the report, this may be useful when you want to trace how a specific variable or state changes over time right before the problem happens.

```javascript
// Manually set value of 15 to property named "credit_balance"
// any time it changes
Bugsee.trace("credit_balance", 15);
```

### Logging

You can use Bugsee logging interface directly, we provide two API functions for send a message to a log:

```javascript
// With default log level (normal)
Bugsee.log("Some log message");

// Set the log level explicitly
// Levels are Bugsee.LogLevel.Error, Bugsee.LogLevel.Warning, Bugsee.LogLevel.Debug, Bugsee.LogLevel.Info, Bugsee.LogLevel.Verbose,
Bugsee.log("Some log message", Bugsee.LogLevel.Info);
```

### Manual invocation

#### Trigger Report

In addition to detection of shake gesture or screenshot issue report view can be triggered programmatically from within
your Cordova application:

```javascript
Bugsee.showReportDialog();
```

Optionally you can pre-fill some fields (summary, description, severity, user will be able to modify them later.

```javascript
// Bugsee.showReportDialog(summary, description, severity)
Bugsee.showReportDialog(
  "Problem summary",
  "Further description",
  Bugsee.Severity.Medium
);
```

#### Upload from code

User doesn't have to be involved, you can also generate and upload a report automatically from your code.

```javascript
// Bugsee.assert(summary, description, severity)
Bugsee.upload(
  "Problem summary",
  "Further description",
  Bugsee.Severity.Blocker
);
```

Bugsee can be further customized. For a complete SDK documentation covering additional options and API's visit [https://docs.bugsee.com](https://docs.bugsee.com)
