#!/bin/bash
# Copyright (c) Bugsee, Inc.

set -x

THIS_SCRIPT_PATH="$(readlink -f "${BASH_SOURCE[0]}")"
SCRIPTS_DIR="$(dirname "$THIS_SCRIPT_PATH")"

export BUGSEE_HERMES_ENGINE_PATH="$PODS_ROOT/hermes-engine"
export BUGSEE_HERMES_CLI_PATH="$BUGSEE_HERMES_ENGINE_PATH/destroot/bin/hermesc"

if [[ -z "$BUGSEE_ORIGINAL_DIR" ]]; then
    export BUGSEE_ORIGINAL_DIR="$PWD"

    TARGET_SCRIPT_DIR="$1"

    if [[ -n "$2" ]]; then
      # we have two arguments. Target script should be the last one
      . $1
      TARGET_SCRIPT_DIR="$2"
      shift
    fi

    export BUGSEE_ORIGINAL_NODE_BINARY="$NODE_BINARY"

    # we have only one argument - target script, which we
    # have put into "TARGET_SCRIPT_DIR" above. To prevent
    # its passing to the "TARGET_SCRIPT_DIR" we remove
    # this one extra argument
    shift

    export NODE_BINARY="$THIS_SCRIPT_PATH"

    if [[ -z "$SOURCEMAP_FILE" ]]; then
      # add and override package sourcemap destination
      if [[ -z "$BUGSEE_PACKAGER_SOURCEMAP_FILE" ]]; then
          export BUGSEE_PACKAGER_SOURCEMAP_FILE="$DERIVED_FILE_DIR/main.jsbundle.map"
      fi
      export EXTRA_PACKAGER_ARGS="$EXTRA_PACKAGER_ARGS --sourcemap-output $BUGSEE_PACKAGER_SOURCEMAP_FILE"

      if [[ -f "$BUGSEE_HERMES_CLI_PATH" ]]; then
          # replace Hermes CLI path to forcefully add option to
          # produce sourcemap
          export HERMES_CLI_PATH="$SCRIPTS_DIR/hermes-wrap.sh"

          if [[ -z "$USE_HERMES" ]]; then
            # we need to set this here as in RN below 0.71.1
            # there is a bug in a build script which causes
            # incorrect USE_HERMES check
            # Fixed here:
            # https://github.com/facebook/react-native/commit/03de19745eec9a0d4d1075bac48639ecf1d41352
            export USE_HERMES=true
          fi
      fi
    fi

    # execute target script
    . "$TARGET_SCRIPT_DIR"
    
    # execute hermes sourcemap generation script
    . "$SCRIPTS_DIR/hermes-sourcemaps.sh"

    if [[ ! -z "$BUGSEE_FINAL_SOURCEMAP_FILE" ]]; then
      "$BUGSEE_ORIGINAL_NODE_BINARY" "$SCRIPTS_DIR"/extract-and-upload-sourcemaps.js bundle --platform ios --sourcemap-output "$BUGSEE_FINAL_SOURCEMAP_FILE"
    fi

    export NODE_BINARY="$BUGSEE_ORIGINAL_NODE_BINARY"
else
    # execute original command
    "$BUGSEE_ORIGINAL_NODE_BINARY" $@
    
    if [[ -z "$SOURCEMAP_FILE" ]]; then
      # execute our auxiliary script to prepare and trigger
      # sourcemaps upload

      # detect whether Hermes engine is being used
      BUGSEE_USE_HERMES=false
      if [[ $USE_HERMES == true ]]; then
        BUGSEE_USE_HERMES=true
      else
        if [[ -z "$USE_HERMES" && -f "$BUGSEE_HERMES_CLI_PATH" ]]; then
          BUGSEE_USE_HERMES=true
        fi

        if [[ -f "$BUGSEE_HERMES_ENGINE_PATH" && ! -f "$BUGSEE_HERMES_CLI_PATH" ]]; then
          BUGSEE_USE_HERMES=false
        fi
      fi
      
      # if Hermes is enabled, then we need to gather sourcemaps
      # after the whole build is complete. Thus, we don't do
      # anything here and postpone sourcemaps uploading to
      # the final stage
      if [[ $BUGSEE_USE_HERMES == false ]]; then
        "$BUGSEE_ORIGINAL_NODE_BINARY" "$SCRIPTS_DIR"/extract-and-upload-sourcemaps.js $@
      fi
    fi
fi
