import { NativeModules, NativeEventEmitter } from 'react-native';
let nativeBridge = null;
/**
 * Checks whether native bridge is created and creates
 * it if it's not
 */
function ensureBridgeExists() {
    if (!nativeBridge) {
        nativeBridge = new NativeEventEmitter(NativeModules.Bugsee);
    }
}
/**
 * Adds new listener callback for the specified event on the native
 * bridge
 *
 * @param eventName Name of the event to subscribe to
 * @param eventCallback Callback which will be called when specified event is raised
 */
export function addNativeEventListener(eventName, eventCallback) {
    ensureBridgeExists();
    nativeBridge?.addListener(eventName, eventCallback);
}
/**
 * Remove all previously added listeners for the specified event
 *
 * @param eventName Event name to remove listeners assigned to
 */
export function removeAllListeners(eventName) {
    ensureBridgeExists();
    nativeBridge?.removeAllListeners(eventName);
}
