import { NativeModules } from 'react-native';
import { isArray, autoParseJson } from '../common/utils';
import { ComponentState } from '../common/componentState';
const NativeBridge = NativeModules.Bugsee;
const handlerTimeout = 20000;
const componentState = new ComponentState({
    enabled: true,
    flagName: 'attachmentsHandler',
    nativeEventName: 'bgsAttachmentsEvent',
    // eslint-disable-next-line no-use-before-define
    nativeEventHandler,
    handlerTimeout,
});
async function nativeEventHandler(rawEvent) {
    const parsedEvent = autoParseJson(rawEvent);
    if (!parsedEvent?.id || !parsedEvent?.report) {
        return;
    }
    const { id } = parsedEvent;
    if (!componentState.launched || !componentState.enabled || !componentState.handlerSet) {
        NativeBridge.setAttachments(JSON.stringify({ id, attachments: [] }));
        return;
    }
    let attachments = null;
    try {
        attachments = await componentState.executeHandler(parsedEvent.report);
        attachments = isArray(attachments) ? attachments : [];
        for (let i = 0; i < attachments.length; i += 1) {
            const attachment = attachments[i];
            if (attachment && attachment.data && typeof attachment.data !== 'string') {
                attachment.data = JSON.stringify(attachment.data);
            }
        }
    }
    catch (e) {
        attachments = [];
    }
    NativeBridge.setAttachments(JSON.stringify({ id, attachments }));
}
export default componentState;
