import { getGlobalObject } from '../../common/utils';
import logger from '../../common/logger';
/**
 * Patch global Promise to make it aligned with the one imported from library.
 *
 * This patch is required, as global Promise in RN versions >=0.63, does not equal to
 * the one imported from the library (versions mismatch).
 *
 */
export function patchGlobalPromise() {
    try {
        /* eslint-disable global-require,import/no-extraneous-dependencies,@typescript-eslint/no-var-requires,import/no-unresolved */
        const { polyfillGlobal } = require('react-native/Libraries/Utilities/PolyfillFunctions');
        // Replicate the way RN initializes its promise library
        const Promise = require('promise/setimmediate/es6-extensions');
        // As of RN 0.67 only 'done' and 'finally' are used
        require('promise/setimmediate/done');
        require('promise/setimmediate/finally');
        polyfillGlobal('Promise', () => Promise);
        /* eslint-enable global-require,import/no-extraneous-dependencies,@typescript-eslint/no-var-requires */
    }
    catch (e) {
        // TODO: Log polyfill error
    }
}
export function checkPromiseVersion() {
    let failed = false;
    try {
        // eslint-disable-next-line global-require, import/no-extraneous-dependencies, @typescript-eslint/no-var-requires
        const RNPromise = require('promise/setimmediate/core');
        const $global = getGlobalObject();
        failed = RNPromise !== $global.Promise;
    }
    catch (e) {
        failed = true;
    }
    if (failed) {
        logger.warn('Unhandled promise rejections may not be caught. Global Promise does not equal to the one RN uses.');
    }
}
export function patchRegejectionTracking(state, rejectionCallback) {
    // TODO: complete method implementation
    //
    // try {
    //   // eslint-disable-next-line global-require, import/no-extraneous-dependencies, @typescript-eslint/no-var-requires
    //   const tracker = require('promise/setimmediate/rejection-tracking');
    //   const originalEnable = tracker.enable;
    //   const originalDisable = tracker.disable;
    //   let enabling = false;
    //   tracker.enable = function enable(...args: unknown[]): unknown {
    //     enabling = true;
    //     // eslint-disable-next-line no-param-reassign
    //     args = args || [];
    //     // eslint-disable-next-line no-param-reassign
    //     args[0] = args[0] || {};
    //     const options = args[0];
    //     try {
    //       return originalEnable(...args);
    //     } finally {
    //       // finally is required to reset this flag
    //       enabling = false;
    //     }
    //   };
    //   tracker.disable = function disable(...args: unknown[]): unknown {
    //     if (!enabling) {
    //       // TODO: keep our implementation injected regardless of the change being made
    //     }
    //     return originalDisable(...args);
    //   };
    // } catch (e) {
    //   // ignore
    // }
}
