import { NativeModules } from 'react-native';
import { ComponentState } from '../../common/componentState';
import { omit, pick, clone, autoParseJson } from '../../common/utils';
// import patchXhr from './patches/xhr';
import patchWebSocket from './patches/ws';
const componentState = new ComponentState({
    controlOptionName: 'MonitorNetwork',
    flagName: 'netFilter',
    nativeEventName: 'bgsNetFilterEvent',
    // eslint-disable-next-line no-use-before-define
    nativeEventHandler,
    // eslint-disable-next-line no-use-before-define
    initCallback,
});
const NativeBridge = NativeModules.Bugsee;
const INTERNAL_NET_FIELDS = [
    'id',
    'timestamp',
    'net_type',
    'isSupplement',
    'isFiltered',
    'override',
];
const READ_ONLY_NET_FIELDS = ['type', 'method', 'size', 'no_body_reason'];
async function filterEvent(rawNetEvent) {
    if (componentState.launched && componentState.enabled) {
        const internalEvent = pick(rawNetEvent, INTERNAL_NET_FIELDS);
        const cleanEvent = clone(omit(rawNetEvent, INTERNAL_NET_FIELDS), true);
        if (cleanEvent) {
            let userEvent;
            try {
                userEvent = await componentState.executeHandler(cleanEvent);
            }
            catch (e) {
                userEvent = null;
            }
            userEvent = omit(userEvent, INTERNAL_NET_FIELDS);
            return {
                ...userEvent,
                ...internalEvent,
                ...pick(rawNetEvent, READ_ONLY_NET_FIELDS),
                isFiltered: true,
            };
        }
    }
    // eslint-disable-next-line no-param-reassign
    rawNetEvent.isFiltered = true;
    return rawNetEvent;
}
async function handleNetworkEvent(netEvent) {
    if (componentState.launched && componentState.enabled) {
        const filteredEvent = await filterEvent(netEvent);
        if (filteredEvent) {
            NativeBridge.logNetworkEvent(JSON.stringify(filteredEvent));
        }
    }
}
async function nativeEventHandler(originalEvent) {
    if (componentState.launched && componentState.enabled) {
        const parsedEvent = autoParseJson(originalEvent);
        if (parsedEvent) {
            await handleNetworkEvent(parsedEvent);
        }
    }
}
function initCallback(state) {
    if (!state.options?.skipPatching) {
        // TODO: this may produce duplicated network events!!!
        // patchXhr(componentState, handleNetworkEvent);
        patchWebSocket(componentState, handleNetworkEvent);
    }
}
export default componentState;
