import { DEFAULT_NETWORK_BODY_SIZE_LIMIT } from '../../../common/constants';
import { getGlobalObject, guid, markObjectAsPatched } from '../../../common/utils';
import { BugseeNetworkType, NoBodyReason, } from '../../../types';
function createWrapper(originalWebSocket, state, eventCallback) {
    async function registerEvent(ws, eventName, rawBody, errorMessage) {
        // eslint-disable-next-line no-underscore-dangle
        if (!state.enabled || !state.launched || !ws?.__bgs) {
            return;
        }
        const timestamp = Date.now();
        // eslint-disable-next-line no-underscore-dangle
        const { id, url } = ws.__bgs;
        const bodySizeLimit = state.options?.maxNetworkBodySize ?? DEFAULT_NETWORK_BODY_SIZE_LIMIT;
        let body;
        let noBodyReason;
        if (rawBody) {
            if (typeof rawBody === 'string') {
                body = rawBody;
            }
            else {
                try {
                    body = await new Response(rawBody).text();
                }
                catch (e) {
                    noBodyReason = NoBodyReason.CantReadData;
                }
            }
            if (body && body.length > bodySizeLimit) {
                body = null;
                noBodyReason = NoBodyReason.SizeTooLarge;
            }
        }
        eventCallback({
            id,
            url,
            timestamp,
            net_type: BugseeNetworkType.BugseeWebSocket,
            method: '',
            type: eventName,
            body,
            size: body ? body.length : 0,
            no_body_reason: noBodyReason,
            error: errorMessage,
        });
    }
    return class WebSocketWrap extends originalWebSocket {
        constructor(uri, protocols) {
            super(uri, protocols);
            // eslint-disable-next-line no-underscore-dangle
            this.__bgs = {
                id: guid(),
                url: uri,
            };
            // TODO: don't we need to register 'opn' upon instantiation?
            this.addEventListener('open', () => {
                registerEvent(this, 'open');
            });
            this.addEventListener('close', () => {
                registerEvent(this, 'close');
            });
            this.addEventListener('message', (e) => {
                registerEvent(this, 'message', e.data);
            });
            this.addEventListener('error', (e) => {
                registerEvent(this, 'error', null, e.message);
            });
        }
        send(data) {
            registerEvent(this, 'send', data);
            return super.send(data);
        }
    };
}
export default function patchWebSocket(state, eventCallback) {
    const $global = getGlobalObject();
    if (!$global.WebSocket.bugseePatched) {
        const OriginalWS = $global.WebSocket;
        $global.WebSocket = createWrapper(OriginalWS, state, eventCallback);
        // TODO: probably it makes sense to set flags in global scope?
        markObjectAsPatched($global.WebSocket);
        markObjectAsPatched(OriginalWS);
    }
}
