import { getBuildId, getRuntimeVersion, getWrapperVersion } from '../version';
/**
 * Base launch options class that contains generic logic
 */
export default class BugseeLaunchOptions {
    $options = new Map();
    $localOptions = new Map();
    constructor() {
        this.$setDefaults();
    }
    /**
     * @protected
     */
    $setDefaults() {
        this.$options.clear();
    }
    /**
     * @protected
     */
    $set(key, val) {
        const opts = this.$options;
        if (val === undefined) {
            if (opts.has(key)) {
                opts.delete(key);
            }
        }
        else {
            opts.set(key, val);
        }
    }
    /**
     * @protected
     */
    $get(key) {
        return this.$options.get(key);
    }
    /**
     * @inner
     */
    $serialize(includeLocal) {
        const result = includeLocal ? this.$serializeLocal() : {};
        this.$options.forEach((v, k) => {
            result[k] = v;
        });
        return result;
    }
    /**
     * @inner
     */
    $serializeLocal() {
        const result = {};
        this.$localOptions.forEach((v, k) => {
            result[k] = v;
        });
        return result;
    }
    static serialize(launchOptions, includeLocal) {
        const serializedOptions = launchOptions instanceof BugseeLaunchOptions
            ? launchOptions.$serialize(includeLocal)
            : { ...(launchOptions || {}) };
        const wrapperVersion = getWrapperVersion();
        serializedOptions.wrapper_info = {
            type: 'react',
            ...wrapperVersion,
            runtime: {
                version: getRuntimeVersion(),
            },
        };
        serializedOptions.buildUUID = getBuildId();
        return serializedOptions;
    }
    /**
     * Adds custom option to the set
     * @public
     * @param key {String}
     * @param val {*}
     */
    setCustomOption(key, val) {
        this.$options.set(key, val);
    }
    get handleRejections() {
        return this.$localOptions.get('handleRejections');
    }
    set handleRejections(val) {
        this.$localOptions.set('handleRejections', val);
    }
    get maxNetworkBodySize() {
        return this.$localOptions.get('maxNetworkBodySize');
    }
    set maxNetworkBodySize(val) {
        this.$localOptions.set('maxNetworkBodySize', val);
    }
    /**
     * Use shake gesture to bring up the built-in the bug reporting UI
     */
    get shakeToReport() {
        return this.$get('ShakeToReport');
    }
    /**
     * Use shake gesture to bring up the built-in the bug reporting UI
     */
    set shakeToReport(val) {
        this.$set('ShakeToReport', val);
    }
    get crashReport() {
        return this.$get('CrashReport');
    }
    set crashReport(val) {
        this.$set('CrashReport', val);
    }
    get maxRecordingTime() {
        return this.$get('MaxRecordingTime');
    }
    set maxRecordingTime(val) {
        this.$set('MaxRecordingTime', val);
    }
    get videoEnabled() {
        return this.$get('VideoEnabled');
    }
    set videoEnabled(val) {
        this.$set('VideoEnabled', val);
    }
    get screenshotEnabled() {
        return this.$get('ScreenshotEnabled');
    }
    set screenshotEnabled(val) {
        this.$set('ScreenshotEnabled', val);
    }
    get captureLogs() {
        return this.$get('CaptureLogs');
    }
    set captureLogs(val) {
        this.$set('CaptureLogs', val);
    }
    get monitorNetwork() {
        return this.$get('MonitorNetwork');
    }
    set monitorNetwork(val) {
        this.$set('MonitorNetwork', val);
        // this is set to true as in iOS we store values
        // in both variants (in BugseeOptions and as
        // raw dictionary)
        this.$set('monitorNetwork', val);
    }
    get wifiOnlyUpload() {
        return this.$get('WifiOnlyUpload');
    }
    set wifiOnlyUpload(val) {
        this.$set('WifiOnlyUpload', val);
    }
    get maxDataSize() {
        return this.$get('MaxDataSize');
    }
    set maxDataSize(val) {
        this.$set('MaxDataSize', val);
    }
    get reportPrioritySelector() {
        return this.$get('BugseeReportPrioritySelector');
    }
    set reportPrioritySelector(val) {
        this.$set('BugseeReportPrioritySelector', val);
    }
    get defaultCrashPriority() {
        return this.$get('BugseeDefaultCrashPriority');
    }
    set defaultCrashPriority(val) {
        this.$set('BugseeDefaultCrashPriority', val);
    }
    get defaultBugPriority() {
        return this.$get('BugseeDefaultBugPriority');
    }
    set defaultBugPriority(val) {
        this.$set('BugseeDefaultBugPriority', val);
    }
    get frameRate() {
        return this.$get('FrameRate');
    }
    set frameRate(val) {
        this.$set('FrameRate', val);
    }
    get minFrameRate() {
        return this.$get('MinFrameRate');
    }
    set minFrameRate(val) {
        this.$set('MinFrameRate', val);
    }
    get maxFrameRate() {
        return this.$get('MaxFrameRate');
    }
    set maxFrameRate(val) {
        this.$set('MaxFrameRate', val);
    }
    get captureDeviceAndNetworkNames() {
        return this.$get('CaptureDeviceAndNetworkNames');
    }
    set captureDeviceAndNetworkNames(val) {
        this.$set('CaptureDeviceAndNetworkNames', val);
    }
    get reportSummaryRequired() {
        return this.$get('ReportSummaryRequired');
    }
    set reportSummaryRequired(val) {
        this.$set('ReportSummaryRequired', val);
    }
    get reportDescriptionRequired() {
        return this.$get('ReportDescriptionRequired');
    }
    set reportDescriptionRequired(val) {
        this.$set('ReportDescriptionRequired', val);
    }
    get reportEmailRequired() {
        return this.$get('ReportEmailRequired');
    }
    set reportEmailRequired(val) {
        this.$set('ReportEmailRequired', val);
    }
}
