import { DEFAULT_NETWORK_BODY_SIZE_LIMIT } from '../common/constants';
import { FrameRate, Severity } from '../types';
import BugseeLaunchOptions from './options.base';
/**
 * Class that holds all the available options used to launch Bugsee with on iOS device
 */
export default class IOSLaunchOptions extends BugseeLaunchOptions {
    $setDefaults() {
        super.$setDefaults();
        // This is set to false by default on iOS,
        // as the new privacy rools forbid sending
        // disk space information off the device
        this.monitorDiskSpace = false;
        this.captureDeviceAndNetworkNames = false;
        this.captureLogs = true;
        this.crashReport = true;
        this.defaultBugPriority = Severity.Low;
        this.defaultCrashPriority = Severity.Blocker;
        this.killDetection = false;
        this.maxRecordingTime = 60;
        this.monitorNetwork = true;
        this.reportPrioritySelector = false;
        this.screenshotToReport = true;
        this.shakeToReport = false;
        // this.style = ???
        this.videoEnabled = true;
        this.frameRate = FrameRate.High;
        this.minFrameRate = 1;
        this.maxFrameRate = 30;
        this.screenshotEnabled = true;
        this.wifiOnlyUpload = false;
        this.maxDataSize = 50;
        this.videoScale = 1.0;
        this.monitorBluetoothStatus = false;
        this.maxNetworkBodySize = DEFAULT_NETWORK_BODY_SIZE_LIMIT;
        this.captureAVPlayer = false;
    }
    get monitorDiskSpace() {
        return this.$get('MonitorDiskSpace');
    }
    set monitorDiskSpace(val) {
        this.$set('MonitorDiskSpace', val);
    }
    get screenshotToReport() {
        return this.$get('ScreenshotToReport');
    }
    set screenshotToReport(val) {
        this.$set('ScreenshotToReport', val);
    }
    get killDetection() {
        return this.$get('BugseeKillDetectionKey');
    }
    set killDetection(val) {
        this.$set('BugseeKillDetectionKey', val);
    }
    get videoScale() {
        return this.$get('VideoScale');
    }
    set videoScale(val) {
        this.$set('VideoScale', val);
    }
    get monitorBluetoothStatus() {
        return this.$get('MonitorBluetoothStatus');
    }
    set monitorBluetoothStatus(val) {
        this.$set('MonitorBluetoothStatus', val);
    }
    /**
     * When enabled, videos playing via AVPlayerLayer
     * will be captured on video. May incur additional
     * performance overhead
     */
    get captureAVPlayer() {
        return this.$get('CaptureAVPlayer');
    }
    /**
     * When enabled, videos playing via AVPlayerLayer
     * will be captured on video. May incur additional
     * performance overhead
     */
    set captureAVPlayer(val) {
        this.$set('CaptureAVPlayer', val);
    }
}
