import { NativeModules, Platform } from 'react-native';
import { isDevMode, sha1 } from './common/utils';
const CURRENT_VERSION = Object.freeze({
    version: '5.4.1',
    build: '7d34e1a',
});
const CURRENT_OS = Platform.OS;
const NativeBridge = NativeModules.Bugsee;
let version = '';
let build = '';
let buildId = '';
let runtimeVersion = '';
export function getWrapperVersion() {
    return CURRENT_VERSION;
}
export function getVersion() {
    return version;
}
export function getBuild() {
    return build;
}
export function getBuildId() {
    return buildId;
}
export async function setAppVersion(appVersion, appBuild) {
    const configStr = isDevMode() ? 'debug' : 'release';
    if (appVersion) {
        version = (appVersion || '').toString();
        build = (appBuild || '').toString();
        buildId = sha1(`${appVersion}-${configStr}-${CURRENT_OS}`);
    }
    else if (!buildId) {
        try {
            const versions = await NativeBridge.getVersions();
            if (!buildId) {
                version = versions?.version || '';
                build = (versions?.build || '').toString();
                buildId = sha1(`${version}-${configStr}-${CURRENT_OS}`);
            }
        }
        catch (e) {
            // ignore
        }
    }
    return Promise.resolve();
}
export function getRuntimeVersion() {
    if (!runtimeVersion) {
        try {
            // eslint-disable-next-line global-require, @typescript-eslint/no-var-requires, import/no-unresolved
            const { major, minor, patch } = require('react-native/Libraries/Core/ReactNativeVersion');
            runtimeVersion = `${major}.${minor}.${patch}`;
        }
        catch (e) {
            // ignore
        }
    }
    return runtimeVersion;
}
